from zope.interface import Interface
# -*- Additional Imports Here -*-


class IItyouQrcodeLayer(Interface):
    """ A layer specific to this product.
        this layer is registered using browserlayer.xml in the package 
        default GenericSetup profile
    """